==> zio-aws-servicecatalog_2.13-5.17.158.4-sources.jar: zio/aws/servicecatalog/model/UpdateServiceActionResponse.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateServiceActionResponse(
    serviceActionDetail: Option[
      zio.aws.servicecatalog.model.ServiceActionDetail
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.UpdateServiceActionResponse = {
    import UpdateServiceActionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.UpdateServiceActionResponse
      .builder()
      .optionallyWith(serviceActionDetail.map(value => value.buildAwsValue()))(
        _.serviceActionDetail
      )
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.UpdateServiceActionResponse.ReadOnly =
    zio.aws.servicecatalog.model.UpdateServiceActionResponse
      .wrap(buildAwsValue())
}
object UpdateServiceActionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.UpdateServiceActionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.servicecatalog.model.UpdateServiceActionResponse =
      zio.aws.servicecatalog.model.UpdateServiceActionResponse(
        serviceActionDetail.map(value => value.asEditable)
      )
    def serviceActionDetail
        : Option[zio.aws.servicecatalog.model.ServiceActionDetail.ReadOnly]
    def getServiceActionDetail: ZIO[
      Any,
      AwsError,
      zio.aws.servicecatalog.model.ServiceActionDetail.ReadOnly
    ] = AwsError.unwrapOptionField("serviceActionDetail", serviceActionDetail)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.UpdateServiceActionResponse
  ) extends zio.aws.servicecatalog.model.UpdateServiceActionResponse.ReadOnly {
    override val serviceActionDetail
        : Option[zio.aws.servicecatalog.model.ServiceActionDetail.ReadOnly] =
      scala
        .Option(impl.serviceActionDetail())
        .map(value =>
          zio.aws.servicecatalog.model.ServiceActionDetail.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.UpdateServiceActionResponse
  ): zio.aws.servicecatalog.model.UpdateServiceActionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-servicecatalog_2.13-5.17.174.1-sources.jar: zio/aws/servicecatalog/model/UpdateServiceActionResponse.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateServiceActionResponse(
    serviceActionDetail: Optional[
      zio.aws.servicecatalog.model.ServiceActionDetail
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.UpdateServiceActionResponse = {
    import UpdateServiceActionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.UpdateServiceActionResponse
      .builder()
      .optionallyWith(serviceActionDetail.map(value => value.buildAwsValue()))(
        _.serviceActionDetail
      )
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.UpdateServiceActionResponse.ReadOnly =
    zio.aws.servicecatalog.model.UpdateServiceActionResponse
      .wrap(buildAwsValue())
}
object UpdateServiceActionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.UpdateServiceActionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.servicecatalog.model.UpdateServiceActionResponse =
      zio.aws.servicecatalog.model.UpdateServiceActionResponse(
        serviceActionDetail.map(value => value.asEditable)
      )
    def serviceActionDetail
        : Optional[zio.aws.servicecatalog.model.ServiceActionDetail.ReadOnly]
    def getServiceActionDetail: ZIO[
      Any,
      AwsError,
      zio.aws.servicecatalog.model.ServiceActionDetail.ReadOnly
    ] = AwsError.unwrapOptionField("serviceActionDetail", serviceActionDetail)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.UpdateServiceActionResponse
  ) extends zio.aws.servicecatalog.model.UpdateServiceActionResponse.ReadOnly {
    override val serviceActionDetail
        : Optional[zio.aws.servicecatalog.model.ServiceActionDetail.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.serviceActionDetail())
        .map(value =>
          zio.aws.servicecatalog.model.ServiceActionDetail.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.UpdateServiceActionResponse
  ): zio.aws.servicecatalog.model.UpdateServiceActionResponse.ReadOnly =
    new Wrapper(impl)
}
